# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Test-Directory
Version:	0.052
Release:	1.%{__distinit}%{__distvers}
Summary:	Perl extension for maintaining test directories
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Test-Directory
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-Directory-%{version}.tar.gz
BuildArch:	noarch
# Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module
BuildRequires:	perl(Carp)
BuildRequires:	perl(Fcntl)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp) >= 0.19
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Builder::Module)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(constant)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::Builder::Tester)
BuildRequires:	perl(Test::Exception)
BuildRequires:	perl(Test::More)
# Runtime
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
Testing code can involve making sure that files are created and deleted as
expected. Doing this manually can be error prone, as it's easy to forget a
file, or miss that some unexpected file was added. This module simplifies
maintaining test directories by tracking their status as they are modified or
tested with this API, making it simple to test both individual files, as well
as to verify that there are no missing or unknown files.

The idea is to use this API to create a temporary directory and populate an
initial set of files. Then, whenever something in the directory changes, use
the test methods to verify that the change happened as expected. At any time,
it is simple to verify that the contents of the directory are exactly as
expected.

Test::Directory implements an object-oriented interface for managing test
directories. It tracks which files it knows about (by creating or testing them
via its API), and can report if any files were missing or unexpectedly added.
There are two flavors of methods for interacting with the directory. Utility
methods simply return a value (i.e. the number of files/errors) with no output,
while the Test functions use Test::Builder to produce the appropriate test
results and diagnostics for the test harness.

The directory will be automatically cleaned up when the object goes out of
scope.

%prep
%setup -q -n Test-Directory-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes README
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Directory.3*

%changelog
* Mon Feb 27 2023 Paul Howarth <paul@city-fan.org> - 0.052-1
- Update to 0.052
  - Fix error message on failure to remove directory in 'clean'
    (GH#2, CPAN RT#130570)
- Use SPDX-format license tag

* Wed Sep 25 2019 Paul Howarth <paul@city-fan.org> - 0.051-1
- Update to 0.051
  - Fix merge issues that prevented some features from being released

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 0.041-8
- Perl 5.30 rebuild

* Tue Apr 10 2018 Paul Howarth <paul@city-fan.org> - 0.041-3
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Fri Sep 30 2016 Paul Howarth <paul@city-fan.org> - 0.041-2
- BR: perl-generators where available
- Simplify find command using -delete

* Fri Mar 21 2014 Paul Howarth <paul@city-fan.org> - 0.041-1
- Initial RPM version
